@@ -42,7 +42,7 @@ from tqdm.notebook import tqdm
 class Heat(Simulation):
     """Heat
 
-    Base class for heat simulations.
+    Heat simulations including laser excitation and N-temperature model.
 
     Args:
         S (Structure): sample to do simulations with.
@@ -183,7 +183,7 @@ class Heat(Simulation):
                  self.intp_at_interface, self._excitation,
                  self._boundary_conditions, self.distances]
 
-        for key, value in kwargs.items():
+        for value in kwargs.values():
             param.append(value)
 
         return self.S.get_hash(types='heat') + '_' + make_hash_md5(param)
@@ -233,7 +233,7 @@ class Heat(Simulation):
         return init_temp
 
     def check_excitation(self, delays):
-        """check_excitation
+        r"""check_excitation
 
         The optical excitation is a dictionary with fluence
         :math:`F` [J/m²], delays :math:`t` [s] of the pump events, and pulse
@@ -249,6 +249,10 @@ class Heat(Simulation):
 
         and to combine excitations which have overlapping intervalls.
 
+        Moreover the incidence angle :math:`theta` is taken into account for
+        the user-defined incidence fluence in order to project the laser
+        footprint onto the sample surface.
+
         Args:
             delays (ndarray[Quantity]): delays range of simulation [s].
 
@@ -256,7 +260,7 @@ class Heat(Simulation):
             (tuple):
             - *res (list[ndarray[float]])* - resulting list of excitations with
               interpolated delay density around excitations.
-            - *fluence (ndarray[float])* - excitation fluences.
+            - *fluence (ndarray[float])* - projected excitation fluences.
             - *delay_pump (ndarray[float])* - delays of the excitations.
             - *pulse_width (ndarray[float])* - pulse widths of the excitations.
 
@@ -265,6 +269,12 @@ class Heat(Simulation):
         fluence = self._excitation['fluence']
         delay_pump = self._excitation['delay_pump']
         pulse_width = self._excitation['pulse_width']
+        theta = self._excitation['theta']
+
+        fluence = fluence*np.sin(theta)
+        self.disp_message('Surface incidence fluence scaled by factor {:5.4f}'
+                          ' due to incidence angle theta={:5.2f} deg'.format(
+                              np.sin(theta), np.rad2deg(theta)))
 
         # throw warnings if heat diffusion should be enabled
         if (self.S.num_sub_systems > 1) and not self.heat_diffusion:
@@ -392,6 +402,7 @@ class Heat(Simulation):
             by Lambert-Beers law.
 
         """
+        self.disp_message('Absorption profile is calculated by Lambert-Beer\'s law.')
         if distances == []:
             # if no distances are set, calculate the extinction on
             # the middle of each unit cell
@@ -469,7 +480,7 @@ class Heat(Simulation):
            <https://doi.org/10.1103/PhysRevB.87.054437>`_
 
         """
-
+        self.disp_message('Absorption profile is calculated by multilayer formalism.')
         if distances == []:
             # if no distances are set, calculate the extinction on
             # the middle of each unit cell
@@ -599,6 +610,9 @@ class Heat(Simulation):
 
             k = k+m  # set the counter
 
+        self.disp_message('Total reflectivity of {:0.1f} % and transmission '
+                          'of {:0.1f} %.'.format(np.round(R_total*100, 1),
+                                                 np.round(T_total*100, 1)))
         return dAdz, Ints, R_total, T_total
 
     def get_temperature_after_delta_excitation(self, fluence, init_temp, distances=[]):
@@ -628,7 +642,7 @@ class Heat(Simulation):
 
         .. math::
 
-             \left| \int_{T_1}^{T_2} m c(T)\, temp_mapT - \frac{\mbox{d}\alpha}
+             \left| \int_{T_1}^{T_2} m c(T)\, \mbox{d}T - \frac{\mbox{d}\alpha}
              {\mbox{d}z} E_0 \Delta z \right| \stackrel{!}{=} 0
 
         Args:
@@ -719,7 +733,7 @@ class Heat(Simulation):
             self.disp_message('_temp_map_ loaded from file:\n\t' + filename)
         else:
             # file does not exist so calculate and save
-            temp_map, delta_temp_map, checked_excitations = \
+            temp_map, delta_temp_map, _ = \
                 self.calc_temp_map(delays, init_temp)
             self.save(full_filename, {'temp_map': temp_map,
                                       'delta_temp_map': delta_temp_map},
@@ -925,7 +939,7 @@ class Heat(Simulation):
         M = len(delays)
         K = self.S.num_sub_systems
         init_temp = self.check_initial_temperature(init_temp, distances)
-        d_start, _, d_mid = self.S.get_distances_of_layers(False)
+        d_start, _, _ = self.S.get_distances_of_layers(False)
 
         d_distances = np.diff(distances)
         N = len(distances)
